pub struct FileProgress {
pub total_bytes: u64,
pub bytes_read: u64,
}Available on crate feature
fs only.Expand description
How far through a file a read has got.
Fields
total_bytes: u64How many bytes there are to read in all.
bytes_read: u64How many have been read so far.