pub enum TableElementFormat {
Show 14 variants
Character,
Boolean,
Bit,
U8,
I8,
U16,
I16,
U32,
I32,
I64,
F32,
F64,
C32,
M64,
}Expand description
The type of a single element, for the columns whose length is not fixed by their format.
Variants
Character
A: one character.
Boolean
L: a logical.
Bit
X: a bit.
U8
B: an unsigned byte.
I8
S: a signed byte.
U16
U: an unsigned 16-bit integer.
I16
I: a signed 16-bit integer.
U32
V: an unsigned 32-bit integer.
I32
J: a signed 32-bit integer.
I64
K: a signed 64-bit integer.
F32
E: a single precision float.
F64
D: a double precision float.
C32
C: a single precision complex value.
M64
M: a double precision complex value.
Implementations
Sourceimpl TableElementFormat
impl TableElementFormat
Sourcepub fn repeated(&self, count: usize) -> TableColumnFormat
pub fn repeated(&self, count: usize) -> TableColumnFormat
This element type repeated count times, as a fixed-width column format.
That is what a variable length array becomes once its descriptor has said how long it actually is.