Image

Enum Image 

pub enum Image {
    F64(ImageData<f64>),
    F32(ImageData<f32>),
    I32(ImageData<i32>),
    I16(ImageData<i16>),
    U8(ImageData<u8>),
}
One image, in whatever type its BITPIX card called for.

Variants



F64(ImageData<f64>)

A double precision image, from BITPIX -64.



F32(ImageData<f32>)

A single precision image, from BITPIX -32.



I32(ImageData<i32>)

A signed 32-bit image, from BITPIX 32.



I16(ImageData<i16>)

A signed 16-bit image, from BITPIX 16.



U8(ImageData<u8>)

An 8-bit image, from BITPIX 8.

Implementations

Source

impl Image

pub fn width(&self) -> u32

Image width in pixels

pub fn height(&self) -> u32

Image height in pixels

pub fn bayer_pattern(&self) -> &Option<BayerPattern>

The camera bayer pattern or None if the camera is monochrome

pub fn normalized(&self) -> ImageBuffer<Luma<f64>, Vec<f64>>

Returns a normalised version of the image, where all values are converted into f64 in the range of 0.0 - 1.0

pub fn normalized_superpixel( &self, ) -> Result<ImageBuffer<Rgb<f64>, Vec<f64>>, Box<dyn Error + Send + Sync>>

Performs a superpixel demosaic and returns a normalised version. The superpixel algorithm is fast, but essentially cutting the resolution in half.

pub fn rgb_image(&self) -> Result<RgbImage, Box<dyn Error + Send + Sync>>

Converts this image into a RgbImage from image-rs